package com.jiuqi.util;

import java.util.jar.Attributes;
import java.util.jar.Manifest;
import java.io.File;

public class BundleUtils
{
    public static String getBundleId(final String path) {
        return getBundleId(new File(path));
    }
    
    public static String getBundleId(final File path) {
        final Manifest manifest = ManifestUtil.getManifest(path);
        if (manifest == null) {
            return null;
        }
        final Attributes attrs = manifest.getMainAttributes();
        final String bundleId = ManifestUtil.getAttributeValue(attrs, "Bundle-SymbolicName");
        return bundleId;
    }
    
    public static boolean isBundle(final String path) {
        return isBundle(new File(path));
    }
    
    public static boolean isBundle(final File path) {
        final String id = getBundleId(path);
        return id != null && !"".equals(id);
    }
    
    public static boolean isHostBundle(final String path) {
        return isHostBundle(new File(path));
    }
    
    public static boolean isHostBundle(final File path) {
        final Manifest manifest = ManifestUtil.getManifest(path);
        if (manifest == null) {
            return false;
        }
        final Attributes attrs = manifest.getMainAttributes();
        final String bundleId = ManifestUtil.getAttributeValue(attrs, "Bundle-SymbolicName");
        if (bundleId == null) {
            return false;
        }
        final String bundleLocalization = ManifestUtil.getAttributeValue(attrs, "Bundle-Localization");
        return bundleLocalization == null || "plugin".equalsIgnoreCase(bundleLocalization);
    }
    
    public static boolean isFragmentBundle(final String path) {
        return isFragmentBundle(new File(path));
    }
    
    public static boolean isFragmentBundle(final File path) {
        final Manifest manifest = ManifestUtil.getManifest(path);
        if (manifest == null) {
            return false;
        }
        final Attributes attrs = manifest.getMainAttributes();
        final String bundleId = ManifestUtil.getAttributeValue(attrs, "Bundle-SymbolicName");
        if (bundleId == null) {
            return false;
        }
        final String fragmentHost = ManifestUtil.getAttributeValue(attrs, "Fragment-Host");
        if (fragmentHost != null) {
            return true;
        }
        final String bundleLocalization = ManifestUtil.getAttributeValue(attrs, "Bundle-Localization");
        return "fragment".equalsIgnoreCase(bundleLocalization);
    }
}
